arpa2fst
Python wrapper for kaldi's arpa2fst.
Installation
kaldilm can be installed using either conda or pip.
Using conda
conda install -c k2-fsa -c conda-forge kaldilm
Using pip
pip install kaldilm
In case it doesn't work using pip install (you can't import _kaldilm), something
likely failed during the compilation of the native part of this library.
The following steps will show you a more verbose log that can help diagnose the issue:
# Remove the broken version first
pip uninstall kaldilm
pip install -v --no-cache-dir kaldilm
To test that kaldilm is installed successfully, run:
$ python3 -m kaldilm --help
It should display the usage information of kaldilm.
Please create an issue on GitHub
if you encounter any problems while installing kaldilm.
Usage
First, let us see the usage information of kaldi's arpa2fst:
kaldi/src/lmbin$ ./arpa2fst
./arpa2fst
Convert an ARPA format language model into an FST
Usage: arpa2fst [opts] <input-arpa> <output-fst>
e.g.: arpa2fst --disambig-symbol=#0 --read-symbol-table=data/lang/words.txt lm/input.arpa G.fst
Note: When called without switches, the output G.fst will contain
an embedded symbol table. This is compatible with the way a previous
version of arpa2fst worked.
Options:
--bos-symbol : Beginning of sentence symbol (string, default = "<s>")
--disambig-symbol : Disambiguator. If provided (e. g. #0), used on input side of backoff links, and <s> and </s> are replaced with epsilons (string, default = "")
--eos-symbol : End of sentence symbol (string, default = "</s>")
--ilabel-sort : Ilabel-sort the output FST (bool, default = true)
--keep-symbols : Store symbol table with FST. Symbols always saved to FST if symbol tables are neither read or written
(otherwise symbols would be lost entirely) (bool, default = false)
--max-arpa-warnings : Maximum warnings to report on ARPA parsing, 0 to disable, -1 to show all (int, default = 30)
--read-symbol-table : Use existing symbol table (string, default = "")
--write-symbol-table : Write generated symbol table to a file (string, default = "")
kaldilm uses the same arguments as kaldi's arpa2fst:
$ python3 -m kaldilm --help
prints
usage: Python wrapper of kaldi's arpa2fst [-h] [--bos-symbol BOS_SYMBOL]
[--disambig-symbol DISAMBIG_SYMBOL]
[--eos-symbol EOS_SYMBOL]
[--ilabel-sort ILABEL_SORT]
[--keep-symbols KEEP_SYMBOLS]
[--max-arpa-warnings MAX_ARPA_WARNINGS]
[--read-symbol-table READ_SYMBOL_TABLE]
[--write-symbol-table WRITE_SYMBOL_TABLE]
[--max-order MAX_ORDER]
input_arpa [output_fst]
positional arguments:
input_arpa input arpa filename
output_fst Output fst filename. If empty, no output file is
created.
optional arguments:
-h, --help show this help message and exit
--bos-symbol BOS_SYMBOL
Beginning of sentence symbol (default = "<s>")
--disambig-symbol DISAMBIG_SYMBOL
Disambiguator. If provided (e.g., #0), used on input
side of backoff links, and <s> and </s> are replaced
with epsilons (default = "")
--eos-symbol EOS_SYMBOL
End of sentence symbol (default = "</s>")
--ilabel-sort ILABEL_SORT
Ilabel-sort the output FST (default = true)
--keep-symbols KEEP_SYMBOLS
Store symbol table with FST. Symbols always saved to
FST if symboltables are neither read or written
(otherwise symbols would be lost entirely) (default =
false)
--max-arpa-warnings MAX_ARPA_WARNINGS
Maximum warnings to report on ARPA parsing, 0 to
disable, -1 to show all (default = 30)
--read-symbol-table READ_SYMBOL_TABLE
Use existing symbol table (default = "")
--write-symbol-table WRITE_SYMBOL_TABLE
(Write generated symbol table to a file (default = "")
--max-order MAX_ORDER
Maximum order (inclusive) in the arpa file is used to
generate the final FST. If it is -1, all ngram data in
the file are used.If it is 1, only unigram data are
used.If it is 2, only ngram data up to bigram are
used.Default is -1.
It has one extra argument --max-order, which is not present in kaldi's arpa2fst.
Example usage
Suppose you have an arpa file input.arpa with the following content:
\data\
ngram 1=4
ngram 2=2
ngram 3=2
\1-grams:
-5.234679 a -3.3
-3.456783 b
0.0000000 <s> -2.5
-4.333333 </s>
\2-grams:
-1.45678 a b -3.23
-1.30490 <s> a -4.2
\3-grams:
-0.34958 <s> a b
-0.23940 a b </s>
\end\
and the word symbol table is words.txt:
<eps> 0
a 1
b 2
#0 3
<s> 4
</s> 5
Note: Numbers in the arpa file are log10(p), while numbers on arcs
in OpenFst are -log(p) and it is log(p) in k2.
log(10) = 2.3026
| log10(p) | p | log(p) | note |
|---|---|---|---|
| -5.234679 | 0.000006 | -12.053294 | log(p) = log10(p) * log(10), -12.053294 = 2.3026 * (-5.234679) |
| -3.300000 | 0.000501 | -7.598531 | |
| -3.456783 | 0.000349 | -7.959537 | |
| 0.000000 | 1.000000 | 0.000000 | |
| -2.500000 | 0.003162 | -5.756463 | |
| -4.333333 | 0.000046 | -9.977868 | |
| -1.456780 | 0.034932 | -3.354360 | |
| -3.230000 | 0.000589 | -7.437350 | |
| -1.304900 | 0.049556 | -3.004643 | |
| -4.200000 | 0.000063 | -9.670856 | |
| -0.349580 | 0.447116 | -0.804938 | |
| -0.239400 | 0.576235 | -0.551239 |
Caution: All symbols with ID >= the ID of #0 are set to <eps>
during compiling HLG.
See https://github.com/k2-fsa/icefall/blob/243fb9723cb82287ec5a891155ab9e0bc304740d/egs/librispeech/ASR/local/compile_hlg.py#L103
If IDs of <s> and </s> are less than that of #0, the resulting HLG is problematic.
You can use the following code to convert it into an FST.
3-gram
This uses all n-gram data inside the arpa file.
python3 -m kaldilm \
--read-symbol-table="./words.txt" \
--disambig-symbol='#0' \
./input.arpa > G_fst.txt
The resulting G_fst.txt is shown in the following
3 5 1 1 3.00464
3 0 3 0 5.75646
0 1 1 1 12.0533
0 2 2 2 7.95954
0 9.97787
1 4 2 2 3.35436
1 0 3 0 7.59853
2 0 3 0
4 2 3 0 7.43735
4 0.551239
5 4 2 2 0.804938
5 1 3 0 9.67086
which can be visualized in k2 using
import k2
with open('G_fst.txt') as f:
G = k2.Fsa.from_openfst(f.read(), acceptor=False)
G.labels_sym = k2.SymbolTable.from_file('words.txt')
G.aux_labels_sym = k2.SymbolTable.from_file('words.txt')
#G.labels[G.labels >= 3] = 0 # convert symbols with ID >= ID of #0 to eps
G.draw('G.svg', title='G')
G.svg is shown below:
1-gram
It uses only uni-gram data inside the arpa file
since --max-order=1 is used.
python3 -m kaldilm \
--read-symbol-table="./words.txt" \
--disambig-symbol='#0' \
--max-order=1 \
./input.arpa > G_uni_fst.txt
The generated G_uni_fst.txt is
3 0 3 0 5.75646
0 1 1 1 12.0533
0 2 2 2 7.95954
0 9.97787
1 0 3 0 7.59853
2 0 3 0
which can be visualized in k2 using
with open('G_uni_fst.txt') as f:
G = k2.Fsa.from_openfst(f.read(), acceptor=False)
G.labels_sym = k2.SymbolTable.from_file('words.txt')
G.aux_labels_sym = k2.SymbolTable.from_file('words.txt')
#G.labels[G.labels >= 3] = 0 # convert symbols with ID >= ID of #0 to eps
G.draw('G_uni.svg', title='G_uni')
G_uni.svg is shown below:
What's more
Please refer to https://github.com/k2-fsa/icefall/blob/master/egs/librispeech/ASR/prepare.sh
for how kaldilm is used in icefall.
Metadata
Release files for kaldilm 1.15.5
For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.
Source distribution (sdist)
| File | Size | Uploaded | Provenance | |
|---|---|---|---|---|
| kaldilm-1.15.5.tar.gz | 49.8 kB | Without provenance | Details |
Built distributions (wheels)
Total release size: 10.3 MB
Release files / kaldilm-1.15.5.tar.gz
| Download URL | kaldilm-1.15.5.tar.gz |
|---|---|
| Size | 49.8 kB |
| Tags | Source |
|
SHA-256 checksum How to use checksums |
5ca4e222b41719e40bcc3db5f4eafdf80b78d325b8bc14edcda363e540f8ca9d
|
|
BLAKE2b-256 checksum How to use checksums |
252aca2a14812d5dc5bc0517f1a8625a2fbddfb1e518a1e4b955e56856aeff7b
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp315-cp315-win_arm64.whl
| Download URL | kaldilm-1.15.5-cp315-cp315-win_arm64.whl |
|---|---|
| Size | 149.3 kB |
| Tags | CPython 3.15 Windows ARM64 |
|
SHA-256 checksum How to use checksums |
758a5861957a6a2c7fb8ee43191cfd8a8515b160709be43aeafa7c4281cace81
|
|
BLAKE2b-256 checksum How to use checksums |
6d906c664459282bdd934aed147b69b005e9d08c7279fa79a5b8162b498231ca
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.15.0
|
Release files / kaldilm-1.15.5-cp315-cp315-win_amd64.whl
| Download URL | kaldilm-1.15.5-cp315-cp315-win_amd64.whl |
|---|---|
| Size | 156.1 kB |
| Tags | CPython 3.15 Windows x86-64 |
|
SHA-256 checksum How to use checksums |
73405935a67054d5bd04ae1893547869a558c72b269084c6f9475c6b24e64c61
|
|
BLAKE2b-256 checksum How to use checksums |
bd400e24767b3fa7ab9629f253dbfe6f346d8daf96e3c1cb8fa78e40a4be46bf
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp315-cp315-win32.whl
| Download URL | kaldilm-1.15.5-cp315-cp315-win32.whl |
|---|---|
| Size | 139.8 kB |
| Tags | CPython 3.15 Windows x86-32 |
|
SHA-256 checksum How to use checksums |
d398a559d438daf9634d8dbd6e9aa153647421a6c00fd345271908f0ffb742d4
|
|
BLAKE2b-256 checksum How to use checksums |
427895202e98f3e76d490982b5342adfc691c092ec77bc94f8a4d2f6b7a199b9
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp315-cp315-manylinux_2_24_x86_64.manylinux_2_28_x86_64.whl
| Download URL | kaldilm-1.15.5-cp315-cp315-manylinux_2_24_x86_64.manylinux_2_28_x86_64.whl |
|---|---|
| Size | 203.3 kB |
| Tags | CPython 3.15 Linux glibc 2.24+ x86-64 Linux glibc 2.28+ x86-64 |
|
SHA-256 checksum How to use checksums |
7b6e3562d15ff35f2cba009edb8399729382177172a56f62228df4558e41acdb
|
|
BLAKE2b-256 checksum How to use checksums |
728016b615072c9a7a90e102a963f58557eb33e0be733b1fcf45866867fc7706
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp315-cp315-manylinux_2_24_armv7l.manylinux_2_31_armv7l.whl
| Download URL | kaldilm-1.15.5-cp315-cp315-manylinux_2_24_armv7l.manylinux_2_31_armv7l.whl |
|---|---|
| Size | 156.1 kB |
| Tags | CPython 3.15 Linux glibc 2.24+ ARMv7l Linux glibc 2.31+ ARMv7l |
|
SHA-256 checksum How to use checksums |
11f419b0058a3c5e52fc80fab94d44a303ecbc4006ee7da60c49463c034499cc
|
|
BLAKE2b-256 checksum How to use checksums |
3aea2cf7b8b335a8f6f2e8692a4170955d89f306490c7a6bc29c96cc50deff63
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp315-cp315-manylinux2014_aarch64.manylinux_2_17_aarch64.whl
| Download URL | kaldilm-1.15.5-cp315-cp315-manylinux2014_aarch64.manylinux_2_17_aarch64.whl |
|---|---|
| Size | 200.9 kB |
| Tags | CPython 3.15 Linux glibc 2.17+ ARM64 |
|
SHA-256 checksum How to use checksums |
dcc60b5a9657a8706e9f36b8d65ee8c48aa3b1c584423c2450270ecc89b4d2f9
|
|
BLAKE2b-256 checksum How to use checksums |
8fb272953e70760e509e4c06966104a10664a05fc6b30a041ee6b1f13ac5e099
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp315-cp315-macosx_10_15_universal2.whl
| Download URL | kaldilm-1.15.5-cp315-cp315-macosx_10_15_universal2.whl |
|---|---|
| Size | 282.8 kB |
| Tags | CPython 3.15 macOS 10.15+ universal2 (ARM64, x86-64) |
|
SHA-256 checksum How to use checksums |
85470716415a4b06bb0f8f706d604e81c987eb85b822113b545d10f2d9c9eb85
|
|
BLAKE2b-256 checksum How to use checksums |
7c54d9c838aebe033ca079effde67648f7b3e2911632440be8f10f1ab8435e3c
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.15.0
|
Release files / kaldilm-1.15.5-cp314-cp314-win_arm64.whl
| Download URL | kaldilm-1.15.5-cp314-cp314-win_arm64.whl |
|---|---|
| Size | 149.3 kB |
| Tags | CPython 3.14 Windows ARM64 |
|
SHA-256 checksum How to use checksums |
1411ce5e0a10bb58fe76c4de781977db2866b1b135a97520a9d22ccf4d01ce8c
|
|
BLAKE2b-256 checksum How to use checksums |
1529232b5e4d4852e6fac7f839995dab8623a492ea2c176d09dec610fb98425d
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.14.8
|
Release files / kaldilm-1.15.5-cp314-cp314-win_amd64.whl
| Download URL | kaldilm-1.15.5-cp314-cp314-win_amd64.whl |
|---|---|
| Size | 156.1 kB |
| Tags | CPython 3.14 Windows x86-64 |
|
SHA-256 checksum How to use checksums |
4f82606d7502720f774167700b568ee0cd8c669bd017c7747c3627270ae85ad2
|
|
BLAKE2b-256 checksum How to use checksums |
d18a9110445addabba6de59356173691b29dceae756180490ec6d7329f7ab0c2
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp314-cp314-win32.whl
| Download URL | kaldilm-1.15.5-cp314-cp314-win32.whl |
|---|---|
| Size | 139.8 kB |
| Tags | CPython 3.14 Windows x86-32 |
|
SHA-256 checksum How to use checksums |
03ba2d5072399edf9efd144738df3e4b440f1d1e3f4be14e062e1b8294b5dafb
|
|
BLAKE2b-256 checksum How to use checksums |
59bc8ebe75ba24370bfaa49aad0b043b856cf5642da9201c7582a2d055fc728e
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp314-cp314-manylinux_2_24_x86_64.manylinux_2_28_x86_64.whl
| Download URL | kaldilm-1.15.5-cp314-cp314-manylinux_2_24_x86_64.manylinux_2_28_x86_64.whl |
|---|---|
| Size | 203.3 kB |
| Tags | CPython 3.14 Linux glibc 2.24+ x86-64 Linux glibc 2.28+ x86-64 |
|
SHA-256 checksum How to use checksums |
1bdd0eda638ccf43238b8537bbd048cfb4a0a480422f436bc4a5176451ee9ea5
|
|
BLAKE2b-256 checksum How to use checksums |
a9f153652b4f36fc9f96e2348dc82a6f6959ae635cc6d2af620416a6319b811d
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp314-cp314-manylinux_2_24_armv7l.manylinux_2_31_armv7l.whl
| Download URL | kaldilm-1.15.5-cp314-cp314-manylinux_2_24_armv7l.manylinux_2_31_armv7l.whl |
|---|---|
| Size | 156.1 kB |
| Tags | CPython 3.14 Linux glibc 2.24+ ARMv7l Linux glibc 2.31+ ARMv7l |
|
SHA-256 checksum How to use checksums |
10ac23ff18bdb814be6d6e64d37f3596ce7fb2c9a6d2a96d5ec9912e0f71d4cd
|
|
BLAKE2b-256 checksum How to use checksums |
54d8a1031c9b314c01656bffd6786358f4c1e0fda10115e5ca6aa9fbcfb1264c
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp314-cp314-manylinux2014_aarch64.manylinux_2_17_aarch64.whl
| Download URL | kaldilm-1.15.5-cp314-cp314-manylinux2014_aarch64.manylinux_2_17_aarch64.whl |
|---|---|
| Size | 200.9 kB |
| Tags | CPython 3.14 Linux glibc 2.17+ ARM64 |
|
SHA-256 checksum How to use checksums |
e05c95c9b1b800e93f35edfae4b277a18ea192d069e7419a4af4407aed8681f2
|
|
BLAKE2b-256 checksum How to use checksums |
8d9ee126bc667034a3796be353ad7cc652661ae6124b860a52a8494a92ba66ee
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp314-cp314-macosx_10_15_universal2.whl
| Download URL | kaldilm-1.15.5-cp314-cp314-macosx_10_15_universal2.whl |
|---|---|
| Size | 282.8 kB |
| Tags | CPython 3.14 macOS 10.15+ universal2 (ARM64, x86-64) |
|
SHA-256 checksum How to use checksums |
91c8c7d58f91b29c6f25bb1ca49dd1521c4a937726ad53005204d338775dc11d
|
|
BLAKE2b-256 checksum How to use checksums |
f6bb9404e71d99c44b43d2a21897baf49ea4d2b52d3eb022e268a9c582c23d03
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.15.0
|
Release files / kaldilm-1.15.5-cp314-cp314-android_24_x86_64.whl
| Download URL | kaldilm-1.15.5-cp314-cp314-android_24_x86_64.whl |
|---|---|
| Size | 170.0 kB |
| Tags | Android API level 24+ x86-64 CPython 3.14 |
|
SHA-256 checksum How to use checksums |
4553601094269b985bf9ed56fac54a50e2cc54beac0b99ab23941848f11d8806
|
|
BLAKE2b-256 checksum How to use checksums |
d090afecdeab328e454714b33638a6b2eb7d3f3d50383e677fe3127b25d92321
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp314-cp314-android_24_x86.whl
| Download URL | kaldilm-1.15.5-cp314-cp314-android_24_x86.whl |
|---|---|
| Size | 170.5 kB |
| Tags | Android API level 24+ x86-32 CPython 3.14 |
|
SHA-256 checksum How to use checksums |
ce952e7bce496794eeb8829cfe35e7e0e27a78163cd9fa1cea01d13c94b66069
|
|
BLAKE2b-256 checksum How to use checksums |
2a52c8d1f9c27d6d089e8ddecaf1171ec4da5e756daa5c43f527fd69b4cc1940
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp314-cp314-android_24_armeabi_v7a.whl
| Download URL | kaldilm-1.15.5-cp314-cp314-android_24_armeabi_v7a.whl |
|---|---|
| Size | 144.9 kB |
| Tags | Android API level 24+ ARM EABI v7a CPython 3.14 |
|
SHA-256 checksum How to use checksums |
06e3ffb023d1ae37874583705be22cbee5b714a86aebff829ad7f24ffcb27cbc
|
|
BLAKE2b-256 checksum How to use checksums |
279dd85b861994b3dfbfaaf424c1af795e2f9adb7103ef85a2cc3034c4d86782
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp314-cp314-android_24_arm64_v8a.whl
| Download URL | kaldilm-1.15.5-cp314-cp314-android_24_arm64_v8a.whl |
|---|---|
| Size | 164.4 kB |
| Tags | Android API level 24+ ARM64 v8a CPython 3.14 |
|
SHA-256 checksum How to use checksums |
1c149214cb5f8399bd9184276d3248441776d64d92bf9d2f8119bf5671d27d7b
|
|
BLAKE2b-256 checksum How to use checksums |
db8f119ac0634e4a774cdc6cd7413d91c12cb0c723ac6ed4100bd082c848f5c3
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp313-cp313-win_arm64.whl
| Download URL | kaldilm-1.15.5-cp313-cp313-win_arm64.whl |
|---|---|
| Size | 145.0 kB |
| Tags | CPython 3.13 Windows ARM64 |
|
SHA-256 checksum How to use checksums |
c9eeb06b24ccb17232af9d10a7205bc2733fd004dd1e6bacff5f33d53c033827
|
|
BLAKE2b-256 checksum How to use checksums |
a9193ac3f5d407afc471617427777df45c8bd0c0577e11099eb83dd5cc299a3b
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.13.16
|
Release files / kaldilm-1.15.5-cp313-cp313-win_amd64.whl
| Download URL | kaldilm-1.15.5-cp313-cp313-win_amd64.whl |
|---|---|
| Size | 152.1 kB |
| Tags | CPython 3.13 Windows x86-64 |
|
SHA-256 checksum How to use checksums |
0bac2396c404f556c80c854c7b4eb2151592b84e0bd5d9272f06dd878beabd03
|
|
BLAKE2b-256 checksum How to use checksums |
f39eae38af20549c91df9551ec41148bc098ff13c430a10156bd2aa2d45c5a6e
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp313-cp313-win32.whl
| Download URL | kaldilm-1.15.5-cp313-cp313-win32.whl |
|---|---|
| Size | 136.0 kB |
| Tags | CPython 3.13 Windows x86-32 |
|
SHA-256 checksum How to use checksums |
1c8b5e7fe9a1d071b05cf7fcd3547cf770b6fb52153231d5ba1eea9823db22fb
|
|
BLAKE2b-256 checksum How to use checksums |
7eb960f703d78d4a7ea6438905cd882a811ca3c8fa61988794ea33ac588571bd
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp313-cp313-manylinux_2_24_x86_64.manylinux_2_28_x86_64.whl
| Download URL | kaldilm-1.15.5-cp313-cp313-manylinux_2_24_x86_64.manylinux_2_28_x86_64.whl |
|---|---|
| Size | 203.3 kB |
| Tags | CPython 3.13 Linux glibc 2.24+ x86-64 Linux glibc 2.28+ x86-64 |
|
SHA-256 checksum How to use checksums |
cf5d2397c26ef0a5edc730b211ddb71637afed3ffde10e92e1cc8188847aa3f0
|
|
BLAKE2b-256 checksum How to use checksums |
035a662d9f22c9f954fc2df1367fb5d1884cdb8ed4f50c9bf7f707e2bf2758cd
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp313-cp313-manylinux_2_24_armv7l.manylinux_2_31_armv7l.whl
| Download URL | kaldilm-1.15.5-cp313-cp313-manylinux_2_24_armv7l.manylinux_2_31_armv7l.whl |
|---|---|
| Size | 156.2 kB |
| Tags | CPython 3.13 Linux glibc 2.24+ ARMv7l Linux glibc 2.31+ ARMv7l |
|
SHA-256 checksum How to use checksums |
027b65880ea557aa4529a30057ad05df527ab5bbee4619b6a783f69d048d042d
|
|
BLAKE2b-256 checksum How to use checksums |
b605baf4c3def89d759c822f5beda4f6f3d892dc206ad9885b605feb7c1442f7
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp313-cp313-manylinux2014_aarch64.manylinux_2_17_aarch64.whl
| Download URL | kaldilm-1.15.5-cp313-cp313-manylinux2014_aarch64.manylinux_2_17_aarch64.whl |
|---|---|
| Size | 200.8 kB |
| Tags | CPython 3.13 Linux glibc 2.17+ ARM64 |
|
SHA-256 checksum How to use checksums |
4ffd51c083fe1496c9df9cef92aed103e49c6569be0446a266c5da630ac28cd5
|
|
BLAKE2b-256 checksum How to use checksums |
46456e82acc4122f3a8d6759fe981879857830c9e830d8274f1a6de2d551d483
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp313-cp313-macosx_10_15_universal2.whl
| Download URL | kaldilm-1.15.5-cp313-cp313-macosx_10_15_universal2.whl |
|---|---|
| Size | 282.6 kB |
| Tags | CPython 3.13 macOS 10.15+ universal2 (ARM64, x86-64) |
|
SHA-256 checksum How to use checksums |
99f5b53295cae875b8afcf1150ce12f7ebfbb97c162aaf359a9295a5070506bd
|
|
BLAKE2b-256 checksum How to use checksums |
f00e990af8739cdf3dbeb664f378705f165ac69d08a1cf7b691710f4b8ad369a
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.15.0
|
Release files / kaldilm-1.15.5-cp312-cp312-win_arm64.whl
| Download URL | kaldilm-1.15.5-cp312-cp312-win_arm64.whl |
|---|---|
| Size | 145.0 kB |
| Tags | CPython 3.12 Windows ARM64 |
|
SHA-256 checksum How to use checksums |
c524d9a6bea013c5334fd4cd3eed527d14ac0ab83506e699d6b44d6ef8209705
|
|
BLAKE2b-256 checksum How to use checksums |
57cefe9337fb2ffca3173698e1eff2152182e839ecd07d54b67bd9b9aed70475
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp312-cp312-win_amd64.whl
| Download URL | kaldilm-1.15.5-cp312-cp312-win_amd64.whl |
|---|---|
| Size | 152.1 kB |
| Tags | CPython 3.12 Windows x86-64 |
|
SHA-256 checksum How to use checksums |
30d31c97ebf2feccc408a82cb5f5284f715e7826c2661e5d4808e3d4748afdf3
|
|
BLAKE2b-256 checksum How to use checksums |
0f902e33f97e276a61c0986b71401930ce5a95bfd5b8d118ca1e7366b88ba935
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp312-cp312-win32.whl
| Download URL | kaldilm-1.15.5-cp312-cp312-win32.whl |
|---|---|
| Size | 135.9 kB |
| Tags | CPython 3.12 Windows x86-32 |
|
SHA-256 checksum How to use checksums |
57e29bbf719ed9e1b648ed14b8a0307947d8569004bb5b7aab189516c97462da
|
|
BLAKE2b-256 checksum How to use checksums |
a8a5070d21b8af2be0b620a11a5f488845e5081e02c45c1acad658537fe50c05
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp312-cp312-manylinux_2_24_x86_64.manylinux_2_28_x86_64.whl
| Download URL | kaldilm-1.15.5-cp312-cp312-manylinux_2_24_x86_64.manylinux_2_28_x86_64.whl |
|---|---|
| Size | 203.4 kB |
| Tags | CPython 3.12 Linux glibc 2.24+ x86-64 Linux glibc 2.28+ x86-64 |
|
SHA-256 checksum How to use checksums |
a3ed6d4682d0f23f957d713f2334ada1101dc1e55e921cc4cb0440b111512998
|
|
BLAKE2b-256 checksum How to use checksums |
d4395123cba6cd231e6a2ee786ac4b7b63f5091d485d8933b99c3a59729fc006
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp312-cp312-manylinux_2_24_armv7l.manylinux_2_31_armv7l.whl
| Download URL | kaldilm-1.15.5-cp312-cp312-manylinux_2_24_armv7l.manylinux_2_31_armv7l.whl |
|---|---|
| Size | 156.2 kB |
| Tags | CPython 3.12 Linux glibc 2.24+ ARMv7l Linux glibc 2.31+ ARMv7l |
|
SHA-256 checksum How to use checksums |
cc6fcce14e4e604924dc6b350f82dfb4b46ad858f58f635db0a740e3b555774d
|
|
BLAKE2b-256 checksum How to use checksums |
b55cf27248d59f7dd273f9f14fab28caf01f7b821d4c77c57ef162818850a3d2
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp312-cp312-manylinux2014_aarch64.manylinux_2_17_aarch64.whl
| Download URL | kaldilm-1.15.5-cp312-cp312-manylinux2014_aarch64.manylinux_2_17_aarch64.whl |
|---|---|
| Size | 200.7 kB |
| Tags | CPython 3.12 Linux glibc 2.17+ ARM64 |
|
SHA-256 checksum How to use checksums |
9b20f42c5b1ec59a24bf8c637e35eb8e4e1f0143f152b255ef839abf7717e831
|
|
BLAKE2b-256 checksum How to use checksums |
58731c3d1c25ede47178d965247485e12bbf67d84cfb3c5571be3a82955c65b3
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp312-cp312-macosx_10_15_universal2.whl
| Download URL | kaldilm-1.15.5-cp312-cp312-macosx_10_15_universal2.whl |
|---|---|
| Size | 282.4 kB |
| Tags | CPython 3.12 macOS 10.15+ universal2 (ARM64, x86-64) |
|
SHA-256 checksum How to use checksums |
121d6cf5f134a6ae3ede26c966147a772c5af5ed55af617d1ea665eb70f72c43
|
|
BLAKE2b-256 checksum How to use checksums |
04e6aa345a17063217bf559188bd63dd714a77d32e7204ecb810094cbe0bdcfd
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.15.0
|
Release files / kaldilm-1.15.5-cp311-cp311-win_arm64.whl
| Download URL | kaldilm-1.15.5-cp311-cp311-win_arm64.whl |
|---|---|
| Size | 144.3 kB |
| Tags | CPython 3.11 Windows ARM64 |
|
SHA-256 checksum How to use checksums |
aefa6cba27ab8d9383435441954d8d65a0a865effcbba3b502da69d444a68174
|
|
BLAKE2b-256 checksum How to use checksums |
509e80f1be1fd684f0e01802b32550fce2cc8b79ab99df17f89acf103c7cf71b
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.11.9
|
Release files / kaldilm-1.15.5-cp311-cp311-win_amd64.whl
| Download URL | kaldilm-1.15.5-cp311-cp311-win_amd64.whl |
|---|---|
| Size | 151.1 kB |
| Tags | CPython 3.11 Windows x86-64 |
|
SHA-256 checksum How to use checksums |
465d8f795390655150ecdd31c81949ff7228d875701b441801ad2e6d55dfb2e2
|
|
BLAKE2b-256 checksum How to use checksums |
98a3ce65a6b66fc331696a24ee3d4ad895d4fd7ac8a241e091f056890e371265
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp311-cp311-win32.whl
| Download URL | kaldilm-1.15.5-cp311-cp311-win32.whl |
|---|---|
| Size | 135.3 kB |
| Tags | CPython 3.11 Windows x86-32 |
|
SHA-256 checksum How to use checksums |
220e8f5c6ca74ee21804c0c0840f21ed0b4a33f6fe7ff6396ed7099a4b8c6eca
|
|
BLAKE2b-256 checksum How to use checksums |
52d7eb2d8be59d69028d934fb7d4cefdc227bbed69b47949ec31bc06af3f3867
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp311-cp311-manylinux_2_24_x86_64.manylinux_2_28_x86_64.whl
| Download URL | kaldilm-1.15.5-cp311-cp311-manylinux_2_24_x86_64.manylinux_2_28_x86_64.whl |
|---|---|
| Size | 202.2 kB |
| Tags | CPython 3.11 Linux glibc 2.24+ x86-64 Linux glibc 2.28+ x86-64 |
|
SHA-256 checksum How to use checksums |
7eaa5c4b188dff7ccc6cefdda87531173a793b9dad8e228f1c5b663179fa491c
|
|
BLAKE2b-256 checksum How to use checksums |
58a31460331982c8d74793cc00e20221430901e70e53d7b4c55f622271e9ad5e
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp311-cp311-manylinux_2_24_armv7l.manylinux_2_31_armv7l.whl
| Download URL | kaldilm-1.15.5-cp311-cp311-manylinux_2_24_armv7l.manylinux_2_31_armv7l.whl |
|---|---|
| Size | 156.0 kB |
| Tags | CPython 3.11 Linux glibc 2.24+ ARMv7l Linux glibc 2.31+ ARMv7l |
|
SHA-256 checksum How to use checksums |
192f2edf7da51359c0db1577135e6dcb5e9417e350b15c5a17cec020e782560a
|
|
BLAKE2b-256 checksum How to use checksums |
b866a80ca5b8dd36b6ddb79f3de33a2cfe7ed812af0b991118d362e5e70d31aa
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp311-cp311-manylinux2014_aarch64.manylinux_2_17_aarch64.whl
| Download URL | kaldilm-1.15.5-cp311-cp311-manylinux2014_aarch64.manylinux_2_17_aarch64.whl |
|---|---|
| Size | 200.6 kB |
| Tags | CPython 3.11 Linux glibc 2.17+ ARM64 |
|
SHA-256 checksum How to use checksums |
1b6d801120d2a21ed2d3606a08a738dd9bc74082be6908ac7cd8a6c7ae777e1c
|
|
BLAKE2b-256 checksum How to use checksums |
9ef99a63a89eedae79b01cd58d30eb7757d27a25be63d7aa373a06345298ab2f
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp311-cp311-macosx_10_15_universal2.whl
| Download URL | kaldilm-1.15.5-cp311-cp311-macosx_10_15_universal2.whl |
|---|---|
| Size | 281.5 kB |
| Tags | CPython 3.11 macOS 10.15+ universal2 (ARM64, x86-64) |
|
SHA-256 checksum How to use checksums |
ef3d6c4f3a6feec38f275734cc1c8c320c7e91dce1c5238676ae1af6db44fc07
|
|
BLAKE2b-256 checksum How to use checksums |
66d2c9f986f39836e598ccf589cf74bc8380780a0f1b2252cef930037cc711f4
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.15.0
|
Release files / kaldilm-1.15.5-cp310-cp310-win_amd64.whl
| Download URL | kaldilm-1.15.5-cp310-cp310-win_amd64.whl |
|---|---|
| Size | 149.9 kB |
| Tags | CPython 3.10 Windows x86-64 |
|
SHA-256 checksum How to use checksums |
10870bec03ae75ce68d6b4b8f18a55f59955c46f7ffd42bc8632806b2287b220
|
|
BLAKE2b-256 checksum How to use checksums |
4642d61bca385301a417da675339ff085f6cf35f7d1266fba3b84a30bdc6b464
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp310-cp310-win32.whl
| Download URL | kaldilm-1.15.5-cp310-cp310-win32.whl |
|---|---|
| Size | 134.3 kB |
| Tags | CPython 3.10 Windows x86-32 |
|
SHA-256 checksum How to use checksums |
bdedb593187a2f143c3e92833274b3681dae34b9668f0ea07ed3e4165f890568
|
|
BLAKE2b-256 checksum How to use checksums |
a66e0409434e787943dec078bb40b5d251bb5b66e9a8d061da7a653cf4ac91aa
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp310-cp310-manylinux_2_24_x86_64.manylinux_2_28_x86_64.whl
| Download URL | kaldilm-1.15.5-cp310-cp310-manylinux_2_24_x86_64.manylinux_2_28_x86_64.whl |
|---|---|
| Size | 200.7 kB |
| Tags | CPython 3.10 Linux glibc 2.24+ x86-64 Linux glibc 2.28+ x86-64 |
|
SHA-256 checksum How to use checksums |
b2cc8c2414e4dd30365dc17569f5c6beda3ce9caa6187b9c84ee15c6ec072f09
|
|
BLAKE2b-256 checksum How to use checksums |
b4fd715f0e4f99e90ec333d527d4bc1bc465952bf17c1d06c809f06ee858a69c
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp310-cp310-manylinux_2_24_armv7l.manylinux_2_31_armv7l.whl
| Download URL | kaldilm-1.15.5-cp310-cp310-manylinux_2_24_armv7l.manylinux_2_31_armv7l.whl |
|---|---|
| Size | 155.1 kB |
| Tags | CPython 3.10 Linux glibc 2.24+ ARMv7l Linux glibc 2.31+ ARMv7l |
|
SHA-256 checksum How to use checksums |
5cc2984b672d97bf55c4e3d0b6aa93c15b22b89fc75a30778a21f6236e8cc3a8
|
|
BLAKE2b-256 checksum How to use checksums |
b195d00af917f89be88cd5793addc7c8da1a9828fc30c2bc60b0001ec7c1300c
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp310-cp310-manylinux2014_aarch64.manylinux_2_17_aarch64.whl
| Download URL | kaldilm-1.15.5-cp310-cp310-manylinux2014_aarch64.manylinux_2_17_aarch64.whl |
|---|---|
| Size | 199.3 kB |
| Tags | CPython 3.10 Linux glibc 2.17+ ARM64 |
|
SHA-256 checksum How to use checksums |
98be3b459af806d25f84182c8c2086c7c0040b4d2c5c43ae4dfd8863748369f0
|
|
BLAKE2b-256 checksum How to use checksums |
7a668d32e6261d910a0a0d634333d3917bb462df89e99f57d8cf85cfe2fa0f0f
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp310-cp310-macosx_10_15_universal2.whl
| Download URL | kaldilm-1.15.5-cp310-cp310-macosx_10_15_universal2.whl |
|---|---|
| Size | 278.7 kB |
| Tags | CPython 3.10 macOS 10.15+ universal2 (ARM64, x86-64) |
|
SHA-256 checksum How to use checksums |
04be76595005df6228c3db831faabcf6a8a565749df65ac3e621f3dad4f8fcfc
|
|
BLAKE2b-256 checksum How to use checksums |
6f0fa09a81cbd2cd4c0b4fbe17c7dfba26d057842ba5a5ab6a79bf548ec5388c
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.15.0
|
Release files / kaldilm-1.15.5-cp39-cp39-win_amd64.whl
| Download URL | kaldilm-1.15.5-cp39-cp39-win_amd64.whl |
|---|---|
| Size | 150.2 kB |
| Tags | CPython 3.9 Windows x86-64 |
|
SHA-256 checksum How to use checksums |
426e710f85fc43f75deb88eb5a175e633bbb674afaf4c420f4f6a51d172df5de
|
|
BLAKE2b-256 checksum How to use checksums |
e02db08d32bb73139bd87c0cfc7316d4b4e89211fd277bc825c93e3ad4b92fd8
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp39-cp39-win32.whl
| Download URL | kaldilm-1.15.5-cp39-cp39-win32.whl |
|---|---|
| Size | 134.5 kB |
| Tags | CPython 3.9 Windows x86-32 |
|
SHA-256 checksum How to use checksums |
59e41a0903fa6f343532d75632d549c9eaff31f4d492ac2f98bdda7f9413590a
|
|
BLAKE2b-256 checksum How to use checksums |
e05f0c9670302a0beb4423620f177ecee1bc735a7bed502fbcfd5e8a1cb3264f
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp39-cp39-manylinux_2_24_x86_64.manylinux_2_28_x86_64.whl
| Download URL | kaldilm-1.15.5-cp39-cp39-manylinux_2_24_x86_64.manylinux_2_28_x86_64.whl |
|---|---|
| Size | 201.0 kB |
| Tags | CPython 3.9 Linux glibc 2.24+ x86-64 Linux glibc 2.28+ x86-64 |
|
SHA-256 checksum How to use checksums |
3c629af71bab211c07dd2dafd70016434e30de9bb7873c5592536588e53a71ed
|
|
BLAKE2b-256 checksum How to use checksums |
97b00933ae0c567507106e912a6309ef0f3fe989aa1cc2a91434b20e09245f97
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp39-cp39-manylinux_2_24_armv7l.manylinux_2_31_armv7l.whl
| Download URL | kaldilm-1.15.5-cp39-cp39-manylinux_2_24_armv7l.manylinux_2_31_armv7l.whl |
|---|---|
| Size | 155.3 kB |
| Tags | CPython 3.9 Linux glibc 2.24+ ARMv7l Linux glibc 2.31+ ARMv7l |
|
SHA-256 checksum How to use checksums |
f1b84e1da94e70a7cbcc201a5be7f3c29b0435ed726efa1c01942846836bc5e5
|
|
BLAKE2b-256 checksum How to use checksums |
0c393d140aa32a7cb6c98cafad3bcda920ceeecb5196f411f98952d88c532a7c
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp39-cp39-manylinux2014_aarch64.manylinux_2_17_aarch64.whl
| Download URL | kaldilm-1.15.5-cp39-cp39-manylinux2014_aarch64.manylinux_2_17_aarch64.whl |
|---|---|
| Size | 199.5 kB |
| Tags | CPython 3.9 Linux glibc 2.17+ ARM64 |
|
SHA-256 checksum How to use checksums |
03e39c726dd411e1d8158e9c79f371cd00b6dbba2b505bfea606c92715393a98
|
|
BLAKE2b-256 checksum How to use checksums |
052416bf25c884871879ba758c9ff522f6cafde0829fc12b0898d8e9f01075e6
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp39-cp39-macosx_10_15_universal2.whl
| Download URL | kaldilm-1.15.5-cp39-cp39-macosx_10_15_universal2.whl |
|---|---|
| Size | 278.8 kB |
| Tags | CPython 3.9 macOS 10.15+ universal2 (ARM64, x86-64) |
|
SHA-256 checksum How to use checksums |
6090270581bcf0b990c9ea658566354dd4e46615503d3ac76d831afc55751cfb
|
|
BLAKE2b-256 checksum How to use checksums |
cdce6640f168b40c693ffaba7043144769c45a2a314255409ac4aa28dbcddb0b
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.15.0
|
Release files / kaldilm-1.15.5-cp38-cp38-win_amd64.whl
| Download URL | kaldilm-1.15.5-cp38-cp38-win_amd64.whl |
|---|---|
| Size | 149.9 kB |
| Tags | CPython 3.8 Windows x86-64 |
|
SHA-256 checksum How to use checksums |
ee60f2acca0e8b8e4e6a8d65bbe7e0cd78ddda1765e34a2bb3662156f9922dcb
|
|
BLAKE2b-256 checksum How to use checksums |
75ce7aa8bcb8a8a28b370cdea84d21fb1f8eb0923df6f7a2e2a99b220dc2721c
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp38-cp38-win32.whl
| Download URL | kaldilm-1.15.5-cp38-cp38-win32.whl |
|---|---|
| Size | 134.2 kB |
| Tags | CPython 3.8 Windows x86-32 |
|
SHA-256 checksum How to use checksums |
47a80920e8be8413a6d93893d9285bbf7d00d3dd1a440a7fdc12fbcff85e2015
|
|
BLAKE2b-256 checksum How to use checksums |
34d22bbe17baa1c04914e5230f6d05abf74c4fadd3f3ff17161f2733a588ffa4
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.10
|
Release files / kaldilm-1.15.5-cp38-cp38-manylinux2014_x86_64.manylinux_2_17_x86_64.whl
| Download URL | kaldilm-1.15.5-cp38-cp38-manylinux2014_x86_64.manylinux_2_17_x86_64.whl |
|---|---|
| Size | 209.3 kB |
| Tags | CPython 3.8 Linux glibc 2.17+ x86-64 |
|
SHA-256 checksum How to use checksums |
278dbfa84326aece054341e8f13a6fd196167ee6171fbdfe1e7f57cec53e5375
|
|
BLAKE2b-256 checksum How to use checksums |
92e077765c7c98aef529b49f3b327c32286b564ae4cd68e1c8f2b97458b7db7c
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp38-cp38-manylinux2014_aarch64.manylinux_2_17_aarch64.whl
| Download URL | kaldilm-1.15.5-cp38-cp38-manylinux2014_aarch64.manylinux_2_17_aarch64.whl |
|---|---|
| Size | 199.0 kB |
| Tags | CPython 3.8 Linux glibc 2.17+ ARM64 |
|
SHA-256 checksum How to use checksums |
dfa0355290bfac1e66be1bc7b5775f2a83ba1a6006c3554424dd0b9d74178684
|
|
BLAKE2b-256 checksum How to use checksums |
e0ab690de6dc9d9034328419b412883daf262d53eaff57b2d9ea88c7eeba0d1f
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.12.3
|
Release files / kaldilm-1.15.5-cp38-cp38-macosx_10_15_universal2.whl
| Download URL | kaldilm-1.15.5-cp38-cp38-macosx_10_15_universal2.whl |
|---|---|
| Size | 278.3 kB |
| Tags | CPython 3.8 macOS 10.15+ universal2 (ARM64, x86-64) |
|
SHA-256 checksum How to use checksums |
8edb65d37ac9d1b4c172521a22c88662356a748aaf61bcfa0c67606c108df6f0
|
|
BLAKE2b-256 checksum How to use checksums |
14eed26687e51096169897c11ae287ae408f5f44595e46eed4e885db4b411796
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/5.0.0 CPython/3.15.0
|
Security for kaldilm 1.15.5
Provenance
Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.
No provenance found
None of the files in this release were uploaded with provenance metadata.
A note on package security
PyPI is a repository for distributing packages, not a service for auditing them. While third-party security researchers and our staff do their best to detect and remove malicious packages, PyPI cannot guarantee the quality, security or suitability of any given package.
To learn more about protecting yourself from malicious actors, visit our package security documentation.